#include "mbed.h"
#include "sht7X.h"
#include <stdio.h>
#include "ms5611.h"


SHT75 sht(PTA13, PTD5); //clock, data
Serial pc(USBTX, USBRX);
Serial o2_flux(PTE0, PTE1);  // tx, rx
ms5611 ms(PTC9, PTC8, ms5611::CSBpin_0);

void sht75_meas(void);
void o2_meas(void);
void press_meas(void);

int main()
{
    o2_flux.baud(9600);
    ms.cmd_reset();
    wait(1.0);

    while(1) {
        sht75_meas();
        press_meas();
        o2_meas();

    }//end while
}//end main




void sht75_meas(void)
{
    float temperature;                    // temperature -40 to 120 deg C
    float humidity;                       // relative humidity 1% to 100%
    float humi_f,rh_lin,rh_true;           // working registers for Illustration purposes
    int t;                                // temporary store for the temp ticks
    int h;                                // temp store for the humidity ticks

    sht.readTempTicks(&t);
    temperature = ((float)(t) * 0.01) - 39.61;

    sht.readHumidityTicks(&h);
    humi_f = (float)(h);
    rh_lin = C3 * humi_f * humi_f + C2 * humi_f + C1;
    rh_true=(((temperature/100)-25)*(T1+T2*humi_f)+rh_lin);
    if(rh_true>100)rh_true=100;                             //cut if the value is outside
    if(rh_true<1)rh_true=1;                                 //the physical possible range
    humidity = rh_true;
    pc.printf("Teplota: %2.2f C Rel. vlhkost: %2.2f %%\r\n",temperature, humidity);
    wait(3.0);
}

void o2_meas(void)
{
    char concentration[6];//array for concentration
    char message[40]; //array for data form sensor
    char c;
    uint8_t m=0;//counter
    uint8_t i=0;//counter
    uint8_t n=0;//counter

    while (c!='\n') {
        if(o2_flux.readable()) {
            c=o2_flux.getc();//load characters from sensor to be shure to start from beggining of array
        }
    }
    while (i<38) { 
        if(o2_flux.readable()) {
            message[i]=o2_flux.getc();//load 50 characters from sensor to array
            i++;
        }
    }
    message[i+1]='\0';//insert end char
    while (message[m]!='%') m++; //find % separator for 02 concentration
        m=m+3; //skip % and space
        for(n=0; n<4; n++) concentration[n]=message[m+n]; //load data to another array
        concentration[n+1]='\0';//insert end char
        pc.printf("Koncentrace O2: %s %%\r\n", concentration); //display array
        pc.printf("------------------------------------\r\n"); 
        wait(1.0);
}

void press_meas(void)
{
    double Temp = ms.calcTemp();                         //calculate press and temp, then returns current temperature in degC
    double Press = ms.calcPressure();                    //calculate press and temp, then returns current pressure in mb
    double GetPress = ms.getPressure();                  //returns current pressure in hPa. Does no calculations.  Ususally done after calcTemp()
    pc.printf("Tlak: %.1f hPa  \r\n", Press);
    wait(1.0);

}